# Developer Guide

Welcome to the CGSE developer guide! An in-depth reference on how to contribute to the CGSE.

First thing to know is that this repository is actually a monorepo, meaning it contains a bunch of related but 
self-standing packages with a minimum of interdependencies. These packages are  
